@@ -1,10 +1,9 @@
 library(DanielBiostatistics10th)
 
 # Page 20, Example 2.2.1
-d141 = read.csv(system.file('extdata', 'EXA_C01_S04_01.csv', package = 'DanielBiostatistics10th'))
-head(d141)
-class(d141$AGE) # 'integer'
-class(age <- as.numeric(d141$AGE)) # 'numeric'
+head(EXA_C01_S04_01)
+class(EXA_C01_S04_01$AGE) # 'integer'
+class(age <- as.numeric(EXA_C01_S04_01$AGE)) # 'numeric'
 sort(age) # Page 21, Table 2.2.1 # 'ordered vector'
 
 # Page 23, Example 2.3.1
@@ -20,8 +19,7 @@ print_stats(age) # or some other data input
 # Page 49, Example 2.5.4 (omitted)
 
 # Page 50, Example 2.5.5
-d255 = read.csv(system.file('extdata', 'EXA_C02_S05_05.csv', package = 'DanielBiostatistics10th'))
-head(d255)
-boxplot(d255$GRF, main = c('GRF from Page 50, Example 2.5.5'))
-print_stats(d255$GRF)
-print_freqs(d255$GRF, breaks = seq.int(10, 45, by = 5))
+head(EXA_C02_S05_05)
+boxplot(EXA_C02_S05_05$GRF, main = c('GRF from Page 50, Example 2.5.5'))
+print_stats(EXA_C02_S05_05$GRF)
+print_freqs(EXA_C02_S05_05$GRF, breaks = seq.int(10, 45, by = 5))
